package com.ruoyi.tuya.mapper;

import java.util.List;
import com.ruoyi.tuya.domain.BusTravelExperience;

/**
 * 平台游记(天)Mapper接口
 * 
 * @author zf
 * @date 2022-07-21
 */
public interface BusTravelExperienceMapper 
{
    /**
     * 查询平台游记(天)
     * 
     * @param id 平台游记(天)主键
     * @return 平台游记(天)
     */
    public BusTravelExperience selectBusTravelExperienceById(Long id);

    /**
     * 查询平台游记(天)列表
     * 
     * @param busTravelExperience 平台游记(天)
     * @return 平台游记(天)集合
     */
    public List<BusTravelExperience> selectBusTravelExperienceList(BusTravelExperience busTravelExperience);

    /**
     * 新增平台游记(天)
     * 
     * @param busTravelExperience 平台游记(天)
     * @return 结果
     */
    public int insertBusTravelExperience(BusTravelExperience busTravelExperience);

    /**
     * 修改平台游记(天)
     * 
     * @param busTravelExperience 平台游记(天)
     * @return 结果
     */
    public int updateBusTravelExperience(BusTravelExperience busTravelExperience);

    /**
     * 删除平台游记(天)
     * 
     * @param id 平台游记(天)主键
     * @return 结果
     */
    public int deleteBusTravelExperienceById(Long id);

    /**
     * 批量删除平台游记(天)
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteBusTravelExperienceByIds(Long[] ids);
}
