package com.ruoyi.tuya.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.tuya.domain.BusTravelExperience;
import com.ruoyi.tuya.service.IBusTravelExperienceService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 平台游记(天)Controller
 *
 * @author zf
 * @date 2022-07-21
 */
@RestController
@RequestMapping("/tuya/tuyaexperience")
public class BusTravelExperienceController extends BaseController
{
    @Autowired
    private IBusTravelExperienceService busTravelExperienceService;


    /**
     * 查询平台游记(天)列表
     */
    @PreAuthorize("@ss.hasPermi('tuya:experience:list')")
    @GetMapping("/list")
    public TableDataInfo list(BusTravelExperience busTravelExperience)
    {
        startPage();
        List<BusTravelExperience> list = busTravelExperienceService.selectBusTravelExperienceList(busTravelExperience);
        return getDataTable(list);
    }

    /**
     * 导出平台游记(天)列表
     */
    @PreAuthorize("@ss.hasPermi('tuya:experience:export')")
    @Log(title = "平台游记(天)", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, BusTravelExperience busTravelExperience)
    {
        List<BusTravelExperience> list = busTravelExperienceService.selectBusTravelExperienceList(busTravelExperience);
        ExcelUtil<BusTravelExperience> util = new ExcelUtil<BusTravelExperience>(BusTravelExperience.class);
        util.exportExcel(response, list, "平台游记(天)数据");
    }

    /**
     * 获取平台游记(天)详细信息
     */
    @PreAuthorize("@ss.hasPermi('tuya:experience:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return AjaxResult.success(busTravelExperienceService.selectBusTravelExperienceById(id));
    }

    /**
     * 新增平台游记(天)
     */
    @PreAuthorize("@ss.hasPermi('tuya:experience:add')")
    @Log(title = "平台游记(天)", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody BusTravelExperience busTravelExperience)
    {
        return toAjax(busTravelExperienceService.insertBusTravelExperience(busTravelExperience));
    }

    /**
     * 修改平台游记(天)
     */
    @PreAuthorize("@ss.hasPermi('tuya:experience:edit')")
    @Log(title = "平台游记(天)", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody BusTravelExperience busTravelExperience)
    {
        return toAjax(busTravelExperienceService.updateBusTravelExperience(busTravelExperience));
    }

    /**
     * 删除平台游记(天)
     */
    @PreAuthorize("@ss.hasPermi('tuya:experience:remove')")
    @Log(title = "平台游记(天)", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(busTravelExperienceService.deleteBusTravelExperienceByIds(ids));
    }
}
